type token =
  | IDENT of (string)
  | STRING of (string)
  | NUM of (string)
  | BANG_
  | PERCENT_
  | AMPER_
  | AMPER_AMPER_
  | LPAREN_
  | LPAREN_RPAREN_
  | RPAREN_
  | STAR_
  | PLUS_
  | PLUS_PLUS_
  | COMMA_
  | DASH_
  | DASH_GT_
  | PERIOD_
  | PERIOD_LPAREN_
  | PERIOD_PERIOD_
  | SLASH_
  | SLASH_BACKSL_
  | COLON_
  | COLON_COLON_
  | COLON_LT_
  | COLON_EQ_
  | COLON_GT_
  | SEMI_
  | LT_
  | LT_DASH_
  | LT_DASH_GT_
  | LT_COLON_
  | LT_EQ_
  | LT_GT_
  | EQ_
  | EQ_GT_
  | EQ_UNDER_D_
  | GT_
  | GT_DASH_GT_
  | GT_EQ_
  | QUEST_
  | QUEST_EQ_
  | AROBAS_
  | LBRACK_
  | BACKSL_SLASH_
  | RBRACK_
  | HAT_
  | LBRACE_
  | BAR_
  | BAR_DASH_
  | BAR_BAR_
  | RBRACE_
  | TILDE_
  | MUSTUSE
  | DEFINITION
  | DEPENDS
  | ELSE
  | END
  | EXISTS
  | FALSE
  | FIX
  | FIXPOINT
  | FORALL
  | FUN
  | FUNCTION
  | IF
  | IN
  | INDUCTIVE
  | LET
  | MATCH
  | ON
  | PARAMETER
  | STRUCT
  | THEN
  | THEOREM
  | TRUE
  | WITH
  | BEGINPROOF
  | BEGINNAME of (string)
  | BEGINHEADER
  | ENDPROOF
  | EOF

open Parsing;;
let _ = parse_error;;
# 4 "parsecoq.mly"
Version.add "$Id: parsecoq.mly,v 1.34 2012-04-11 18:27:26 doligez Exp $";;

open Printf;;

open Expr;;
open Namespace;;
open Phrase;;

let rec mk_type_string e =
  match e with
  | Evar (s, _) -> s
  | Emeta _ -> assert false
  | Eapp ("*", [e1; e2], _) ->
     sprintf "(%s*%s)" (mk_type_string e1) (mk_type_string e2)
  | Eapp ("%", [e1; e2], _) ->
     sprintf "((%s)%%%s)" (mk_type_string e1) (mk_type_string e2)
  | Eapp (s, args, _) ->
     let inside =
       List.fold_left (fun s a -> sprintf "%s %s" s (mk_type_string a)) s args
     in
     sprintf "(%s)" inside
  | Eimply (e1, e2, _) ->
     sprintf "(%s -> %s)" (mk_type_string e1) (mk_type_string e2)
  | _ -> assert false (* FIXME TODO *)
;;

let mk_eapp (s, args) =
  match (s, args) with
  | "and", [e1; e2] -> eand (e1, e2)
  | "or", [e1; e2] -> eor (e1, e2)
  | "not", [e1] -> enot (e1)
  | _ -> eapp (s, args)
;;

let mk_apply (e, l) =
  match e with
  | Eapp (s, args, _) -> mk_eapp (s, args @ l)
  | Evar (s, _) -> mk_eapp (s, l)
  | _ -> raise Parse_error
;;

let rec mk_arobas_apply (id, l) =
  match l with
  | Evar ("_", _) :: t -> mk_arobas_apply (id, t)
  | [] -> evar (id)
  | _ -> eapp (id, l)
;;

let mk_all bindings body =
  let f (var, ty) e = eall (evar var, ty, e) in
  List.fold_right f bindings body
;;

let mk_ex bindings body =
  let f (var, ty) e = eex (evar var, ty, e) in
  List.fold_right f bindings body
;;

let mk_lam bindings body =
  let f (var, ty) e = elam (evar var, ty, e) in
  List.fold_right f bindings body
;;

let mk_fix ident ty bindings body =
  let f (var, ty) e = elam (evar var, ty, e) in
  (ident, eapp ("$fix", [ List.fold_right f ((ident, ty) :: bindings) body ]))
;;

let rec get_params e =
  match e with
  | Elam (v, _, body, _) ->
      let (p, e1) = get_params body in
      (v :: p, e1)
  | _ -> ([], e)
;;

let mk_let id expr body =
  substitute_2nd [(evar id, expr)] body
;;

let mk_let_fix (id, def) body = mk_let id def body;;

let mk_pattern (constr, args) body =
  let bindings = List.map (fun v -> (v, "")) args in
  mk_lam bindings (eapp ("$match-case", [evar (constr); body]))
;;

let mk_inductive name bindings constrs =
  let args = List.map fst bindings in
  let g (tcon, targs) =
    if tcon = name && targs = args then Self
    else Param (String.concat " " (tcon :: targs))
  in
  let f (cname, args) = (cname, List.map g args) in
  Inductive (name, args, List.map f constrs, name ^ "_ind")
;;

let mk_pairs e l =
  let f x y = eapp ("@", [evar "Datatypes.pair"; evar "_"; evar "_"; x; y]) in
  List.fold_left f e l
;;

# 190 "parsecoq.ml"
let yytransl_const = [|
  260 (* BANG_ *);
  261 (* PERCENT_ *);
  262 (* AMPER_ *);
  263 (* AMPER_AMPER_ *);
  264 (* LPAREN_ *);
  265 (* LPAREN_RPAREN_ *);
  266 (* RPAREN_ *);
  267 (* STAR_ *);
  268 (* PLUS_ *);
  269 (* PLUS_PLUS_ *);
  270 (* COMMA_ *);
  271 (* DASH_ *);
  272 (* DASH_GT_ *);
  273 (* PERIOD_ *);
  274 (* PERIOD_LPAREN_ *);
  275 (* PERIOD_PERIOD_ *);
  276 (* SLASH_ *);
  277 (* SLASH_BACKSL_ *);
  278 (* COLON_ *);
  279 (* COLON_COLON_ *);
  280 (* COLON_LT_ *);
  281 (* COLON_EQ_ *);
  282 (* COLON_GT_ *);
  283 (* SEMI_ *);
  284 (* LT_ *);
  285 (* LT_DASH_ *);
  286 (* LT_DASH_GT_ *);
  287 (* LT_COLON_ *);
  288 (* LT_EQ_ *);
  289 (* LT_GT_ *);
  290 (* EQ_ *);
  291 (* EQ_GT_ *);
  292 (* EQ_UNDER_D_ *);
  293 (* GT_ *);
  294 (* GT_DASH_GT_ *);
  295 (* GT_EQ_ *);
  296 (* QUEST_ *);
  297 (* QUEST_EQ_ *);
  298 (* AROBAS_ *);
  299 (* LBRACK_ *);
  300 (* BACKSL_SLASH_ *);
  301 (* RBRACK_ *);
  302 (* HAT_ *);
  303 (* LBRACE_ *);
  304 (* BAR_ *);
  305 (* BAR_DASH_ *);
  306 (* BAR_BAR_ *);
  307 (* RBRACE_ *);
  308 (* TILDE_ *);
  309 (* MUSTUSE *);
  310 (* DEFINITION *);
  311 (* DEPENDS *);
  312 (* ELSE *);
  313 (* END *);
  314 (* EXISTS *);
  315 (* FALSE *);
  316 (* FIX *);
  317 (* FIXPOINT *);
  318 (* FORALL *);
  319 (* FUN *);
  320 (* FUNCTION *);
  321 (* IF *);
  322 (* IN *);
  323 (* INDUCTIVE *);
  324 (* LET *);
  325 (* MATCH *);
  326 (* ON *);
  327 (* PARAMETER *);
  328 (* STRUCT *);
  329 (* THEN *);
  330 (* THEOREM *);
  331 (* TRUE *);
  332 (* WITH *);
  333 (* BEGINPROOF *);
  335 (* BEGINHEADER *);
  336 (* ENDPROOF *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  257 (* IDENT *);
  258 (* STRING *);
  259 (* NUM *);
  334 (* BEGINNAME *);
    0|]

let yylhs = "\255\255\
\001\000\001\000\001\000\004\000\004\000\005\000\005\000\003\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\007\000\010\000\010\000\010\000\010\000\
\010\000\010\000\010\000\010\000\011\000\011\000\013\000\013\000\
\009\000\009\000\014\000\014\000\014\000\006\000\006\000\016\000\
\015\000\015\000\017\000\017\000\017\000\012\000\018\000\018\000\
\019\000\019\000\019\000\019\000\019\000\019\000\020\000\020\000\
\022\000\022\000\022\000\002\000\002\000\021\000\021\000\023\000\
\023\000\023\000\024\000\024\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\008\000\008\000\008\000\000\000"

let yylen = "\002\000\
\007\000\003\000\005\000\004\000\002\000\000\000\002\000\004\000\
\004\000\004\000\004\000\006\000\010\000\008\000\005\000\006\000\
\003\000\003\000\003\000\003\000\003\000\003\000\002\000\002\000\
\003\000\002\000\001\000\011\000\001\000\001\000\004\000\005\000\
\005\000\003\000\001\000\001\000\001\000\002\000\002\000\003\000\
\000\000\005\000\003\000\002\000\005\000\001\000\001\000\003\000\
\000\000\002\000\000\000\002\000\004\000\001\000\001\000\001\000\
\005\000\005\000\008\000\012\000\011\000\008\000\000\000\006\000\
\003\000\002\000\001\000\002\000\000\000\005\000\000\000\001\000\
\003\000\005\000\003\000\002\000\000\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\004\000\004\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\029\000\030\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\036\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\035\000\000\000\087\000\
\000\000\000\000\000\000\000\000\067\000\000\000\000\000\000\000\
\023\000\066\000\000\000\056\000\000\000\000\000\000\000\000\000\
\000\000\000\000\046\000\047\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\055\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\024\000\068\000\000\000\
\034\000\000\000\000\000\000\000\025\000\000\000\000\000\000\000\
\065\000\050\000\052\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\007\000\000\000\000\000\
\000\000\000\000\000\000\022\000\021\000\000\000\002\000\000\000\
\038\000\000\000\000\000\000\000\031\000\000\000\000\000\000\000\
\000\000\000\000\000\000\048\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\004\000\000\000\000\000\033\000\032\000\
\040\000\000\000\000\000\058\000\053\000\000\000\000\000\000\000\
\000\000\078\000\081\000\080\000\000\000\082\000\079\000\083\000\
\000\000\084\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\015\000\057\000\000\000\003\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\044\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\086\000\085\000\000\000\000\000\
\000\000\000\000\043\000\000\000\001\000\064\000\059\000\000\000\
\000\000\000\000\062\000\000\000\000\000\000\000\000\000\042\000\
\000\000\000\000\000\000\000\000\000\000\045\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\061\000\
\076\000\000\000\000\000\070\000\000\000\000\000\060\000\000\000\
\075\000\000\000\073\000\000\000\000\000\074\000"

let yydgoto = "\002\000\
\024\000\025\000\123\000\027\000\059\000\041\000\054\000\140\000\
\146\000\028\000\070\000\124\000\076\000\177\000\042\000\043\000\
\044\000\037\000\029\000\079\000\204\000\030\000\235\000\236\000"

let yysindex = "\048\000\
\189\255\000\000\000\000\000\000\069\255\092\255\069\255\051\255\
\081\255\029\255\070\255\000\000\100\255\070\255\070\255\123\255\
\069\255\139\255\009\255\069\255\192\255\000\000\047\255\000\000\
\059\255\121\003\069\255\021\255\000\000\077\001\173\001\021\255\
\000\000\000\000\144\255\000\000\149\255\051\255\070\255\156\255\
\155\255\158\255\000\000\000\000\144\255\175\255\164\255\144\255\
\009\000\101\255\010\255\184\255\212\255\151\255\134\255\000\000\
\197\255\047\255\145\255\223\255\069\255\069\255\069\255\069\255\
\069\255\069\255\232\000\121\003\021\255\000\000\000\000\233\255\
\000\000\069\255\069\255\225\255\000\000\236\255\216\255\069\255\
\000\000\000\000\000\000\156\255\230\255\069\255\069\255\199\255\
\069\255\069\255\217\255\069\255\101\255\227\255\016\003\069\255\
\237\255\070\255\069\255\213\255\069\255\000\000\047\255\243\255\
\183\000\250\254\183\000\000\000\000\000\132\255\000\000\190\255\
\000\000\003\000\133\000\085\001\000\000\250\255\069\255\191\000\
\101\255\183\000\183\000\000\000\203\255\183\000\183\000\069\255\
\249\000\020\000\016\003\016\003\016\003\016\003\016\003\016\003\
\016\003\016\003\016\003\254\255\024\255\016\003\238\255\183\000\
\150\255\226\255\231\001\000\000\069\255\024\001\000\000\000\000\
\000\000\069\255\012\000\000\000\000\000\027\000\249\255\069\255\
\019\000\000\000\000\000\000\000\036\000\000\000\000\000\000\000\
\049\000\000\000\069\255\069\255\050\000\247\255\156\255\171\255\
\031\000\000\000\000\000\033\002\000\000\061\000\069\255\035\000\
\069\255\183\000\030\000\016\003\016\003\170\255\183\000\062\000\
\089\000\000\000\115\255\081\000\069\255\095\001\144\255\091\002\
\075\000\125\000\097\000\083\000\000\000\000\000\069\255\069\255\
\051\000\100\000\000\000\026\001\000\000\000\000\000\000\069\255\
\079\000\086\000\000\000\183\000\017\000\095\000\101\000\000\000\
\080\000\069\255\180\255\069\255\069\255\000\000\069\255\149\002\
\156\255\201\255\030\000\102\000\183\000\094\000\207\002\000\000\
\000\000\201\255\015\255\000\000\180\255\069\255\000\000\114\000\
\000\000\180\255\000\000\183\000\119\000\000\000"

let yyrindex = "\000\000\
\063\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\019\255\000\000\000\000\019\255\114\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\045\255\000\000\
\000\000\136\001\000\000\001\000\000\000\005\000\000\000\059\000\
\000\000\000\000\204\255\000\000\000\000\000\000\241\255\118\000\
\000\000\000\000\000\000\000\000\098\000\000\000\000\000\122\000\
\000\000\126\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\045\255\153\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\073\000\117\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\125\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\074\000\000\000\131\000\000\000\
\000\000\248\254\000\000\103\000\000\000\000\000\071\003\000\000\
\041\001\175\000\099\001\000\000\000\000\233\000\000\000\000\000\
\000\000\000\000\000\000\152\000\000\000\000\000\000\000\000\000\
\074\000\157\001\173\255\000\000\000\000\215\001\017\002\000\000\
\000\000\000\000\011\255\011\255\011\255\165\000\011\255\011\255\
\011\255\165\000\011\255\000\000\000\000\165\000\000\000\075\002\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\144\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\133\002\170\000\011\255\011\255\000\000\191\002\000\000\
\000\000\000\000\172\000\000\000\000\000\000\000\034\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\103\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\249\002\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\129\255\000\000\170\000\003\255\051\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\128\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\008\000\255\255\000\000\228\255\244\255\000\000\204\001\
\239\000\015\000\023\000\146\255\080\001\022\001\224\255\161\001\
\229\255\181\001\029\000\219\255\224\000\000\000\136\255\064\255"

let yytablesize = 1216
let yytable = "\026\000\
\027\000\046\000\047\000\031\000\069\000\033\000\082\000\088\000\
\155\000\051\000\091\000\083\000\072\000\049\000\062\000\049\000\
\052\000\159\000\055\000\072\000\077\000\003\000\094\000\004\000\
\249\000\068\000\064\000\065\000\005\000\102\000\250\000\095\000\
\051\000\067\000\096\000\077\000\034\000\071\000\051\000\061\000\
\049\000\243\000\069\000\182\000\062\000\006\000\069\000\006\000\
\001\000\248\000\072\000\082\000\006\000\063\000\077\000\063\000\
\064\000\065\000\026\000\105\000\106\000\107\000\108\000\109\000\
\110\000\083\000\081\000\066\000\053\000\003\000\039\000\004\000\
\115\000\116\000\148\000\112\000\005\000\040\000\120\000\012\000\
\063\000\035\000\036\000\069\000\122\000\143\000\006\000\126\000\
\127\000\172\000\129\000\113\000\032\000\157\000\141\000\022\000\
\006\000\144\000\038\000\147\000\045\000\093\000\006\000\006\000\
\009\000\225\000\006\000\006\000\040\000\006\000\006\000\013\000\
\006\000\006\000\016\000\084\000\037\000\018\000\238\000\006\000\
\007\000\021\000\006\000\048\000\251\000\058\000\011\000\012\000\
\210\000\253\000\014\000\015\000\060\000\017\000\049\000\049\000\
\019\000\020\000\049\000\050\000\049\000\049\000\194\000\022\000\
\049\000\049\000\049\000\180\000\051\000\061\000\175\000\078\000\
\062\000\005\000\062\000\005\000\084\000\176\000\186\000\049\000\
\005\000\214\000\194\000\063\000\064\000\065\000\064\000\065\000\
\086\000\190\000\191\000\195\000\049\000\080\000\020\000\066\000\
\049\000\066\000\176\000\087\000\233\000\200\000\054\000\202\000\
\097\000\061\000\054\000\234\000\089\000\003\000\062\000\004\000\
\056\000\036\000\005\000\212\000\005\000\054\000\090\000\063\000\
\241\000\233\000\064\000\065\000\005\000\220\000\221\000\054\000\
\242\000\100\000\005\000\005\000\098\000\066\000\005\000\005\000\
\099\000\005\000\101\000\054\000\005\000\005\000\103\000\104\000\
\232\000\063\000\237\000\005\000\055\000\239\000\006\000\111\000\
\019\000\114\000\117\000\207\000\118\000\119\000\128\000\121\000\
\007\000\008\000\009\000\010\000\252\000\125\000\011\000\012\000\
\130\000\013\000\014\000\015\000\016\000\017\000\051\000\018\000\
\019\000\020\000\142\000\021\000\145\000\027\000\049\000\022\000\
\149\000\023\000\027\000\027\000\151\000\150\000\027\000\154\000\
\027\000\027\000\158\000\051\000\161\000\027\000\171\000\181\000\
\061\000\027\000\178\000\184\000\174\000\062\000\027\000\051\000\
\061\000\027\000\027\000\027\000\183\000\062\000\063\000\185\000\
\017\000\064\000\065\000\187\000\027\000\188\000\063\000\027\000\
\027\000\064\000\065\000\027\000\066\000\027\000\027\000\027\000\
\027\000\027\000\189\000\192\000\066\000\027\000\193\000\026\000\
\027\000\197\000\027\000\027\000\026\000\026\000\199\000\027\000\
\026\000\027\000\026\000\026\000\027\000\203\000\069\000\026\000\
\027\000\092\000\228\000\026\000\069\000\201\000\208\000\051\000\
\026\000\209\000\211\000\026\000\026\000\026\000\213\000\051\000\
\216\000\218\000\018\000\219\000\223\000\222\000\026\000\226\000\
\231\000\026\000\026\000\227\000\051\000\026\000\230\000\026\000\
\026\000\026\000\026\000\026\000\229\000\245\000\246\000\026\000\
\051\000\037\000\026\000\249\000\026\000\026\000\037\000\037\000\
\254\000\026\000\037\000\026\000\037\000\037\000\026\000\069\000\
\069\000\037\000\026\000\049\000\061\000\037\000\152\000\063\000\
\063\000\062\000\037\000\051\000\061\000\037\000\037\000\037\000\
\069\000\062\000\063\000\077\000\009\000\064\000\065\000\041\000\
\037\000\039\000\063\000\037\000\037\000\064\000\065\000\037\000\
\066\000\037\000\037\000\037\000\037\000\037\000\077\000\217\000\
\066\000\037\000\049\000\020\000\037\000\049\000\037\000\037\000\
\020\000\020\000\071\000\037\000\020\000\037\000\020\000\020\000\
\037\000\028\000\224\000\153\000\037\000\196\000\061\000\020\000\
\085\000\057\000\244\000\062\000\020\000\000\000\061\000\156\000\
\000\000\020\000\000\000\062\000\063\000\000\000\008\000\064\000\
\065\000\000\000\020\000\000\000\063\000\020\000\020\000\064\000\
\065\000\020\000\066\000\020\000\020\000\020\000\020\000\020\000\
\000\000\000\000\066\000\020\000\000\000\019\000\020\000\000\000\
\020\000\020\000\019\000\019\000\000\000\020\000\019\000\020\000\
\019\000\019\000\020\000\000\000\000\000\000\000\020\000\000\000\
\000\000\019\000\000\000\000\000\000\000\000\000\019\000\000\000\
\061\000\000\000\000\000\019\000\000\000\062\000\000\000\000\000\
\010\000\000\000\000\000\000\000\000\000\000\000\063\000\019\000\
\019\000\064\000\065\000\019\000\000\000\019\000\019\000\019\000\
\019\000\019\000\000\000\000\000\066\000\019\000\000\000\000\000\
\019\000\061\000\019\000\019\000\000\000\017\000\062\000\019\000\
\160\000\019\000\017\000\017\000\019\000\000\000\017\000\063\000\
\019\000\017\000\064\000\065\000\000\000\000\000\000\000\000\000\
\000\000\017\000\000\000\000\000\000\000\066\000\000\000\000\000\
\000\000\145\000\011\000\017\000\000\000\000\000\162\000\163\000\
\164\000\165\000\166\000\167\000\168\000\169\000\170\000\017\000\
\017\000\173\000\000\000\017\000\000\000\017\000\017\000\017\000\
\017\000\017\000\075\000\000\000\061\000\017\000\000\000\018\000\
\017\000\062\000\017\000\017\000\018\000\018\000\000\000\017\000\
\018\000\017\000\063\000\018\000\017\000\064\000\065\000\000\000\
\017\000\000\000\000\000\018\000\000\000\000\000\000\000\000\000\
\066\000\008\000\009\000\010\000\016\000\018\000\000\000\205\000\
\206\000\013\000\000\000\000\000\016\000\000\000\000\000\018\000\
\000\000\018\000\018\000\021\000\000\000\018\000\000\000\018\000\
\018\000\018\000\018\000\018\000\000\000\000\000\000\000\018\000\
\000\000\009\000\018\000\000\000\018\000\018\000\009\000\009\000\
\000\000\018\000\009\000\018\000\000\000\009\000\018\000\000\000\
\000\000\072\000\018\000\000\000\000\000\009\000\073\000\074\000\
\000\000\000\000\075\000\000\000\061\000\000\000\012\000\009\000\
\000\000\062\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\063\000\009\000\009\000\064\000\065\000\009\000\
\000\000\009\000\009\000\009\000\009\000\009\000\000\000\000\000\
\066\000\009\000\000\000\008\000\009\000\000\000\009\000\009\000\
\008\000\008\000\000\000\009\000\008\000\009\000\000\000\008\000\
\009\000\000\000\000\000\000\000\009\000\000\000\000\000\008\000\
\000\000\000\000\000\000\000\000\000\000\000\000\061\000\179\000\
\014\000\008\000\000\000\062\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\063\000\008\000\008\000\064\000\
\065\000\008\000\000\000\008\000\008\000\008\000\008\000\008\000\
\000\000\000\000\066\000\008\000\000\000\010\000\008\000\000\000\
\008\000\008\000\010\000\010\000\000\000\008\000\010\000\008\000\
\000\000\010\000\008\000\000\000\000\000\000\000\008\000\000\000\
\000\000\010\000\000\000\000\000\000\000\000\000\000\000\000\000\
\061\000\198\000\013\000\010\000\000\000\062\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\063\000\010\000\
\010\000\064\000\065\000\010\000\000\000\010\000\010\000\010\000\
\010\000\010\000\000\000\000\000\066\000\010\000\000\000\011\000\
\010\000\000\000\010\000\010\000\011\000\011\000\000\000\010\000\
\011\000\010\000\000\000\011\000\010\000\000\000\000\000\000\000\
\010\000\000\000\000\000\011\000\000\000\000\000\000\000\000\000\
\000\000\000\000\061\000\215\000\000\000\011\000\000\000\062\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\063\000\011\000\011\000\064\000\065\000\011\000\000\000\011\000\
\011\000\011\000\011\000\011\000\000\000\000\000\066\000\011\000\
\000\000\016\000\011\000\000\000\011\000\011\000\016\000\016\000\
\000\000\011\000\016\000\011\000\000\000\016\000\011\000\000\000\
\000\000\000\000\011\000\000\000\000\000\016\000\000\000\000\000\
\000\000\000\000\000\000\000\000\061\000\240\000\000\000\016\000\
\000\000\062\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\063\000\016\000\016\000\064\000\065\000\016\000\
\000\000\016\000\016\000\016\000\016\000\016\000\000\000\000\000\
\066\000\016\000\000\000\012\000\016\000\000\000\016\000\016\000\
\012\000\012\000\000\000\016\000\012\000\016\000\000\000\012\000\
\016\000\000\000\000\000\000\000\016\000\000\000\000\000\012\000\
\000\000\000\000\000\000\000\000\000\000\000\000\061\000\247\000\
\000\000\012\000\000\000\062\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\063\000\012\000\012\000\064\000\
\065\000\012\000\000\000\012\000\012\000\012\000\012\000\012\000\
\000\000\000\000\066\000\012\000\000\000\014\000\012\000\000\000\
\012\000\012\000\014\000\014\000\000\000\012\000\014\000\012\000\
\000\000\014\000\012\000\000\000\000\000\000\000\012\000\000\000\
\131\000\014\000\132\000\000\000\133\000\000\000\000\000\134\000\
\135\000\000\000\136\000\014\000\000\000\000\000\000\000\000\000\
\137\000\138\000\000\000\000\000\000\000\139\000\000\000\014\000\
\014\000\000\000\000\000\014\000\000\000\014\000\014\000\014\000\
\014\000\014\000\000\000\000\000\000\000\014\000\000\000\013\000\
\014\000\000\000\014\000\014\000\013\000\013\000\000\000\014\000\
\013\000\014\000\000\000\013\000\014\000\000\000\000\000\006\000\
\014\000\006\000\000\000\013\000\000\000\000\000\006\000\000\000\
\000\000\000\000\000\000\000\000\000\000\013\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\013\000\013\000\000\000\000\000\013\000\000\000\013\000\
\013\000\013\000\013\000\013\000\000\000\000\000\000\000\013\000\
\006\000\000\000\013\000\000\000\013\000\013\000\000\000\000\000\
\000\000\013\000\006\000\013\000\000\000\000\000\013\000\000\000\
\006\000\006\000\013\000\000\000\006\000\006\000\000\000\006\000\
\061\000\000\000\006\000\006\000\000\000\062\000\000\000\000\000\
\000\000\006\000\000\000\000\000\000\000\000\000\063\000\000\000\
\000\000\064\000\065\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\066\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\008\000\009\000\010\000\
\000\000\000\000\000\000\000\000\000\000\013\000\000\000\000\000\
\016\000\000\000\000\000\018\000\000\000\000\000\000\000\021\000"

let yycheck = "\001\000\
\000\000\014\000\015\000\005\000\000\000\007\000\039\000\045\000\
\119\000\001\001\048\000\039\000\010\001\022\001\021\001\017\000\
\008\001\128\000\020\000\017\001\010\001\001\001\050\000\003\001\
\010\001\027\000\033\001\034\001\008\001\058\000\016\001\022\001\
\014\001\026\000\025\001\025\001\008\000\030\000\047\001\016\001\
\022\001\234\000\028\000\154\000\021\001\001\001\032\000\003\001\
\001\000\242\000\048\001\084\000\008\001\030\001\032\000\022\001\
\033\001\034\001\000\000\061\000\062\000\063\000\064\000\065\000\
\066\000\093\000\038\000\044\001\060\001\001\001\001\001\003\001\
\074\000\075\000\103\000\068\000\008\001\008\001\080\000\059\001\
\047\001\001\001\002\001\069\000\086\000\098\000\042\001\089\000\
\090\000\066\001\092\000\069\000\001\001\121\000\096\000\075\001\
\052\001\099\000\070\001\101\000\001\001\001\001\058\001\059\001\
\054\001\216\000\062\001\063\001\008\001\065\001\042\001\061\001\
\068\001\069\001\064\001\001\001\000\000\067\001\229\000\075\001\
\052\001\071\001\078\001\001\001\245\000\079\001\058\001\059\001\
\014\001\250\000\062\001\063\001\074\001\065\001\010\001\022\001\
\068\001\069\001\010\001\001\001\016\001\017\001\175\000\075\001\
\016\001\017\001\022\001\149\000\035\001\016\001\001\001\008\001\
\021\001\001\001\021\001\003\001\001\001\008\001\160\000\035\001\
\008\001\199\000\195\000\030\001\033\001\034\001\033\001\034\001\
\014\001\171\000\172\000\001\001\048\001\025\001\000\000\044\001\
\048\001\044\001\008\001\022\001\001\001\183\000\010\001\185\000\
\001\001\016\001\014\001\008\001\014\001\001\001\021\001\003\001\
\001\001\002\001\042\001\197\000\008\001\025\001\035\001\030\001\
\233\000\001\001\033\001\034\001\052\001\207\000\208\000\035\001\
\008\001\076\001\058\001\059\001\001\001\044\001\062\001\063\001\
\066\001\065\001\022\001\047\001\068\001\069\001\078\001\001\001\
\226\000\022\001\228\000\075\001\025\001\231\000\042\001\000\000\
\000\000\001\001\010\001\066\001\001\001\022\001\022\001\010\001\
\052\001\053\001\054\001\055\001\246\000\047\001\058\001\059\001\
\022\001\061\001\062\001\063\001\064\001\065\001\014\001\067\001\
\068\001\069\001\022\001\071\001\048\001\005\001\022\001\075\001\
\022\001\077\001\010\001\011\001\010\001\080\001\014\001\022\001\
\016\001\017\001\072\001\035\001\001\001\021\001\025\001\000\000\
\016\001\025\001\057\001\001\001\047\001\021\001\030\001\047\001\
\016\001\033\001\034\001\035\001\025\001\021\001\030\001\047\001\
\000\000\033\001\034\001\025\001\044\001\010\001\030\001\047\001\
\048\001\033\001\034\001\051\001\044\001\053\001\054\001\055\001\
\056\001\057\001\010\001\010\001\044\001\061\001\072\001\005\001\
\064\001\035\001\066\001\067\001\010\001\011\001\010\001\071\001\
\014\001\073\001\016\001\017\001\076\001\048\001\074\001\021\001\
\080\001\073\001\066\001\025\001\080\001\051\001\025\001\014\001\
\030\001\001\001\010\001\033\001\034\001\035\001\000\000\022\001\
\022\001\001\001\000\000\017\001\001\001\051\001\044\001\025\001\
\025\001\047\001\048\001\022\001\035\001\051\001\010\001\053\001\
\054\001\055\001\056\001\057\001\022\001\016\001\025\001\061\001\
\047\001\005\001\064\001\010\001\066\001\067\001\010\001\011\001\
\010\001\071\001\014\001\073\001\016\001\017\001\076\001\000\000\
\074\001\021\001\080\001\022\001\016\001\025\001\010\001\022\001\
\047\001\021\001\030\001\022\001\016\001\033\001\034\001\035\001\
\080\001\021\001\030\001\025\001\000\000\033\001\034\001\057\001\
\044\001\010\001\030\001\047\001\048\001\033\001\034\001\051\001\
\044\001\053\001\054\001\055\001\056\001\057\001\010\001\051\001\
\044\001\061\001\035\001\005\001\064\001\010\001\066\001\067\001\
\010\001\011\001\017\001\071\001\014\001\073\001\016\001\017\001\
\076\001\066\001\212\000\116\000\080\001\176\000\016\001\025\001\
\040\000\021\000\235\000\021\001\030\001\255\255\016\001\017\001\
\255\255\035\001\255\255\021\001\030\001\255\255\000\000\033\001\
\034\001\255\255\044\001\255\255\030\001\047\001\048\001\033\001\
\034\001\051\001\044\001\053\001\054\001\055\001\056\001\057\001\
\255\255\255\255\044\001\061\001\255\255\005\001\064\001\255\255\
\066\001\067\001\010\001\011\001\255\255\071\001\014\001\073\001\
\016\001\017\001\076\001\255\255\255\255\255\255\080\001\255\255\
\255\255\025\001\255\255\255\255\255\255\255\255\030\001\255\255\
\016\001\255\255\255\255\035\001\255\255\021\001\255\255\255\255\
\000\000\255\255\255\255\255\255\255\255\255\255\030\001\047\001\
\048\001\033\001\034\001\051\001\255\255\053\001\054\001\055\001\
\056\001\057\001\255\255\255\255\044\001\061\001\255\255\255\255\
\064\001\016\001\066\001\067\001\255\255\005\001\021\001\071\001\
\056\001\073\001\010\001\011\001\076\001\255\255\014\001\030\001\
\080\001\017\001\033\001\034\001\255\255\255\255\255\255\255\255\
\255\255\025\001\255\255\255\255\255\255\044\001\255\255\255\255\
\255\255\048\001\000\000\035\001\255\255\255\255\131\000\132\000\
\133\000\134\000\135\000\136\000\137\000\138\000\139\000\047\001\
\048\001\142\000\255\255\051\001\255\255\053\001\054\001\055\001\
\056\001\057\001\014\001\255\255\016\001\061\001\255\255\005\001\
\064\001\021\001\066\001\067\001\010\001\011\001\255\255\071\001\
\014\001\073\001\030\001\017\001\076\001\033\001\034\001\255\255\
\080\001\255\255\255\255\025\001\255\255\255\255\255\255\255\255\
\044\001\053\001\054\001\055\001\000\000\035\001\255\255\188\000\
\189\000\061\001\255\255\255\255\064\001\255\255\255\255\067\001\
\255\255\047\001\048\001\071\001\255\255\051\001\255\255\053\001\
\054\001\055\001\056\001\057\001\255\255\255\255\255\255\061\001\
\255\255\005\001\064\001\255\255\066\001\067\001\010\001\011\001\
\255\255\071\001\014\001\073\001\255\255\017\001\076\001\255\255\
\255\255\005\001\080\001\255\255\255\255\025\001\010\001\011\001\
\255\255\255\255\014\001\255\255\016\001\255\255\000\000\035\001\
\255\255\021\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\030\001\047\001\048\001\033\001\034\001\051\001\
\255\255\053\001\054\001\055\001\056\001\057\001\255\255\255\255\
\044\001\061\001\255\255\005\001\064\001\255\255\066\001\067\001\
\010\001\011\001\255\255\071\001\014\001\073\001\255\255\017\001\
\076\001\255\255\255\255\255\255\080\001\255\255\255\255\025\001\
\255\255\255\255\255\255\255\255\255\255\255\255\016\001\017\001\
\000\000\035\001\255\255\021\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\047\001\048\001\033\001\
\034\001\051\001\255\255\053\001\054\001\055\001\056\001\057\001\
\255\255\255\255\044\001\061\001\255\255\005\001\064\001\255\255\
\066\001\067\001\010\001\011\001\255\255\071\001\014\001\073\001\
\255\255\017\001\076\001\255\255\255\255\255\255\080\001\255\255\
\255\255\025\001\255\255\255\255\255\255\255\255\255\255\255\255\
\016\001\017\001\000\000\035\001\255\255\021\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\030\001\047\001\
\048\001\033\001\034\001\051\001\255\255\053\001\054\001\055\001\
\056\001\057\001\255\255\255\255\044\001\061\001\255\255\005\001\
\064\001\255\255\066\001\067\001\010\001\011\001\255\255\071\001\
\014\001\073\001\255\255\017\001\076\001\255\255\255\255\255\255\
\080\001\255\255\255\255\025\001\255\255\255\255\255\255\255\255\
\255\255\255\255\016\001\017\001\255\255\035\001\255\255\021\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\030\001\047\001\048\001\033\001\034\001\051\001\255\255\053\001\
\054\001\055\001\056\001\057\001\255\255\255\255\044\001\061\001\
\255\255\005\001\064\001\255\255\066\001\067\001\010\001\011\001\
\255\255\071\001\014\001\073\001\255\255\017\001\076\001\255\255\
\255\255\255\255\080\001\255\255\255\255\025\001\255\255\255\255\
\255\255\255\255\255\255\255\255\016\001\017\001\255\255\035\001\
\255\255\021\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\030\001\047\001\048\001\033\001\034\001\051\001\
\255\255\053\001\054\001\055\001\056\001\057\001\255\255\255\255\
\044\001\061\001\255\255\005\001\064\001\255\255\066\001\067\001\
\010\001\011\001\255\255\071\001\014\001\073\001\255\255\017\001\
\076\001\255\255\255\255\255\255\080\001\255\255\255\255\025\001\
\255\255\255\255\255\255\255\255\255\255\255\255\016\001\017\001\
\255\255\035\001\255\255\021\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\047\001\048\001\033\001\
\034\001\051\001\255\255\053\001\054\001\055\001\056\001\057\001\
\255\255\255\255\044\001\061\001\255\255\005\001\064\001\255\255\
\066\001\067\001\010\001\011\001\255\255\071\001\014\001\073\001\
\255\255\017\001\076\001\255\255\255\255\255\255\080\001\255\255\
\001\001\025\001\003\001\255\255\005\001\255\255\255\255\008\001\
\009\001\255\255\011\001\035\001\255\255\255\255\255\255\255\255\
\017\001\018\001\255\255\255\255\255\255\022\001\255\255\047\001\
\048\001\255\255\255\255\051\001\255\255\053\001\054\001\055\001\
\056\001\057\001\255\255\255\255\255\255\061\001\255\255\005\001\
\064\001\255\255\066\001\067\001\010\001\011\001\255\255\071\001\
\014\001\073\001\255\255\017\001\076\001\255\255\255\255\001\001\
\080\001\003\001\255\255\025\001\255\255\255\255\008\001\255\255\
\255\255\255\255\255\255\255\255\255\255\035\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\047\001\048\001\255\255\255\255\051\001\255\255\053\001\
\054\001\055\001\056\001\057\001\255\255\255\255\255\255\061\001\
\042\001\255\255\064\001\255\255\066\001\067\001\255\255\255\255\
\255\255\071\001\052\001\073\001\255\255\255\255\076\001\255\255\
\058\001\059\001\080\001\255\255\062\001\063\001\255\255\065\001\
\016\001\255\255\068\001\069\001\255\255\021\001\255\255\255\255\
\255\255\075\001\255\255\255\255\255\255\255\255\030\001\255\255\
\255\255\033\001\034\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\044\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\053\001\054\001\055\001\
\255\255\255\255\255\255\255\255\255\255\061\001\255\255\255\255\
\064\001\255\255\255\255\067\001\255\255\255\255\255\255\071\001"

let yynames_const = "\
  BANG_\000\
  PERCENT_\000\
  AMPER_\000\
  AMPER_AMPER_\000\
  LPAREN_\000\
  LPAREN_RPAREN_\000\
  RPAREN_\000\
  STAR_\000\
  PLUS_\000\
  PLUS_PLUS_\000\
  COMMA_\000\
  DASH_\000\
  DASH_GT_\000\
  PERIOD_\000\
  PERIOD_LPAREN_\000\
  PERIOD_PERIOD_\000\
  SLASH_\000\
  SLASH_BACKSL_\000\
  COLON_\000\
  COLON_COLON_\000\
  COLON_LT_\000\
  COLON_EQ_\000\
  COLON_GT_\000\
  SEMI_\000\
  LT_\000\
  LT_DASH_\000\
  LT_DASH_GT_\000\
  LT_COLON_\000\
  LT_EQ_\000\
  LT_GT_\000\
  EQ_\000\
  EQ_GT_\000\
  EQ_UNDER_D_\000\
  GT_\000\
  GT_DASH_GT_\000\
  GT_EQ_\000\
  QUEST_\000\
  QUEST_EQ_\000\
  AROBAS_\000\
  LBRACK_\000\
  BACKSL_SLASH_\000\
  RBRACK_\000\
  HAT_\000\
  LBRACE_\000\
  BAR_\000\
  BAR_DASH_\000\
  BAR_BAR_\000\
  RBRACE_\000\
  TILDE_\000\
  MUSTUSE\000\
  DEFINITION\000\
  DEPENDS\000\
  ELSE\000\
  END\000\
  EXISTS\000\
  FALSE\000\
  FIX\000\
  FIXPOINT\000\
  FORALL\000\
  FUN\000\
  FUNCTION\000\
  IF\000\
  IN\000\
  INDUCTIVE\000\
  LET\000\
  MATCH\000\
  ON\000\
  PARAMETER\000\
  STRUCT\000\
  THEN\000\
  THEOREM\000\
  TRUE\000\
  WITH\000\
  BEGINPROOF\000\
  BEGINHEADER\000\
  ENDPROOF\000\
  EOF\000\
  "

let yynames_block = "\
  IDENT\000\
  STRING\000\
  NUM\000\
  BEGINNAME\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : 'hyp_def_list) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    Obj.repr(
# 213 "parsecoq.mly"
      ( (_3, (Hyp (goal_name, enot _5, 0), false) :: _1) )
# 821 "parsecoq.ml"
               : string * (Phrase.phrase * bool) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'hyp_def_list) in
    Obj.repr(
# 215 "parsecoq.mly"
      ( (* Error.warn "deprecated input format"; *)
        (thm_default_name, (Hyp (goal_name, enot _1, 0), false) :: _2) )
# 830 "parsecoq.ml"
               : string * (Phrase.phrase * bool) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'proof_head) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'hyp_def_list) in
    Obj.repr(
# 218 "parsecoq.mly"
      ( (* Error.warn "deprecated input format"; *)
        (_1, (Hyp (goal_name, enot _2, 0), false) :: _3) )
# 840 "parsecoq.ml"
               : string * (Phrase.phrase * bool) list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'proofheaders) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'proofheaders) in
    Obj.repr(
# 224 "parsecoq.mly"
      ( _3 )
# 849 "parsecoq.ml"
               : 'proof_head))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'proofheaders) in
    Obj.repr(
# 226 "parsecoq.mly"
      ( "theorem" )
# 856 "parsecoq.ml"
               : 'proof_head))
; (fun __caml_parser_env ->
    Obj.repr(
# 231 "parsecoq.mly"
      ( () )
# 862 "parsecoq.ml"
               : 'proofheaders))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'proofheaders) in
    Obj.repr(
# 233 "parsecoq.mly"
      ( () )
# 869 "parsecoq.ml"
               : 'proofheaders))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'bindings) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 238 "parsecoq.mly"
      ( mk_all _2 _4 )
# 877 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'bindings) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 240 "parsecoq.mly"
      ( mk_ex _2 _4 )
# 885 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'bindings) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 243 "parsecoq.mly"
      ( mk_lam _2 _4 )
# 893 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'fix) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 246 "parsecoq.mly"
      ( mk_let_fix _2 _4 )
# 901 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 249 "parsecoq.mly"
      ( mk_let _2 _4 _6 )
# 910 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 7 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'junk) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _10 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 252 "parsecoq.mly"
      ( mk_let _3 _8 _10 )
# 920 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : 'junk) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 255 "parsecoq.mly"
      ( mk_let _2 _6 _8 )
# 930 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'expr) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'pat_expr_list) in
    Obj.repr(
# 258 "parsecoq.mly"
      ( eapp ("$match", _2 :: _4) )
# 938 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'expr) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 261 "parsecoq.mly"
      ( eapp ("FOCAL.ifthenelse", [_2; _4; _6]) )
# 947 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 264 "parsecoq.mly"
      ( eimply (_1, _3) )
# 955 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 267 "parsecoq.mly"
      ( eequiv (_1, _3) )
# 963 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 270 "parsecoq.mly"
      ( eor (_1, _3) )
# 971 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 273 "parsecoq.mly"
      ( eand (_1, _3) )
# 979 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 276 "parsecoq.mly"
      ( eapp ("=", [_1; _3]) )
# 987 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 278 "parsecoq.mly"
      ( enot (eapp ("=", [_1; _3])) )
# 995 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 281 "parsecoq.mly"
      ( enot (_2) )
# 1002 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'expr1) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'expr1_list) in
    Obj.repr(
# 284 "parsecoq.mly"
      ( mk_apply (_1, _2) )
# 1010 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expr1_list) in
    Obj.repr(
# 287 "parsecoq.mly"
      ( mk_eapp ("@", evar (_2) :: _3) )
# 1018 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 290 "parsecoq.mly"
      ( mk_eapp ("@", [evar (_2)]) )
# 1025 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'expr1) in
    Obj.repr(
# 293 "parsecoq.mly"
      ( _1 )
# 1032 "parsecoq.ml"
               : 'expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 9 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 8 : 'bindings) in
    let _6 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _9 = (Parsing.peek_val __caml_parser_env 2 : 'typ) in
    let _11 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 298 "parsecoq.mly"
      ( mk_fix _2 _9 _3 _11 )
# 1043 "parsecoq.ml"
               : 'fix))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 303 "parsecoq.mly"
      ( evar (_1) )
# 1050 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 305 "parsecoq.mly"
      ( eapp (_1, []) )
# 1057 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expr_list) in
    Obj.repr(
# 308 "parsecoq.mly"
      ( mk_pairs _2 _3 )
# 1065 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'expr) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    Obj.repr(
# 311 "parsecoq.mly"
      ( eapp ("*", [_2; _4]) )
# 1073 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'expr) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 313 "parsecoq.mly"
      ( eapp ("%", [_2; evar (_4)]) )
# 1081 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    Obj.repr(
# 315 "parsecoq.mly"
      ( _2 )
# 1088 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    Obj.repr(
# 317 "parsecoq.mly"
      ( etrue )
# 1094 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    Obj.repr(
# 319 "parsecoq.mly"
      ( efalse )
# 1100 "parsecoq.ml"
               : 'expr1))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'expr1) in
    Obj.repr(
# 323 "parsecoq.mly"
                           ( [_1] )
# 1107 "parsecoq.ml"
               : 'expr1_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'expr1) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'expr1_list) in
    Obj.repr(
# 324 "parsecoq.mly"
                           ( _1 :: _2 )
# 1115 "parsecoq.ml"
               : 'expr1_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 329 "parsecoq.mly"
      ( [_2] )
# 1122 "parsecoq.ml"
               : 'comma_expr_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'comma_expr_list) in
    Obj.repr(
# 331 "parsecoq.mly"
      ( _2 :: _3 )
# 1130 "parsecoq.ml"
               : 'comma_expr_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 336 "parsecoq.mly"
      ( [] )
# 1136 "parsecoq.ml"
               : 'pat_expr_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'pattern) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'pat_expr_list) in
    Obj.repr(
# 338 "parsecoq.mly"
      ( mk_pattern _2 _4 :: _5 )
# 1145 "parsecoq.ml"
               : 'pat_expr_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'pattern) in
    Obj.repr(
# 343 "parsecoq.mly"
      ( _2 )
# 1152 "parsecoq.ml"
               : 'pattern))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'idlist) in
    Obj.repr(
# 345 "parsecoq.mly"
      ( (_1, _2) )
# 1160 "parsecoq.ml"
               : 'pattern))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 347 "parsecoq.mly"
      ( ("Datatypes.pair", [_2; _4]) )
# 1168 "parsecoq.ml"
               : 'pattern))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'simplebinding) in
    Obj.repr(
# 351 "parsecoq.mly"
                           ( _1 )
# 1175 "parsecoq.ml"
               : 'bindings))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'binding_list) in
    Obj.repr(
# 352 "parsecoq.mly"
                           ( _1 )
# 1182 "parsecoq.ml"
               : 'bindings))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'idlist) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'typ) in
    Obj.repr(
# 356 "parsecoq.mly"
                       ( List.map (fun v -> (v, _3)) _1 )
# 1190 "parsecoq.ml"
               : 'simplebinding))
; (fun __caml_parser_env ->
    Obj.repr(
# 360 "parsecoq.mly"
                           ( [] )
# 1196 "parsecoq.ml"
               : 'idlist))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'idlist) in
    Obj.repr(
# 361 "parsecoq.mly"
                           ( _1 :: _2 )
# 1204 "parsecoq.ml"
               : 'idlist))
; (fun __caml_parser_env ->
    Obj.repr(
# 366 "parsecoq.mly"
      ( [] )
# 1210 "parsecoq.ml"
               : 'binding_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'binding_list) in
    Obj.repr(
# 368 "parsecoq.mly"
      ( (_1, "") :: _2 )
# 1218 "parsecoq.ml"
               : 'binding_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'simplebinding) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'binding_list) in
    Obj.repr(
# 370 "parsecoq.mly"
      ( _2 @ _4 )
# 1226 "parsecoq.ml"
               : 'binding_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'expr) in
    Obj.repr(
# 374 "parsecoq.mly"
                           ( mk_type_string _1 )
# 1233 "parsecoq.ml"
               : 'typ))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 379 "parsecoq.mly"
           ( _1 )
# 1240 "parsecoq.ml"
               : 'id_or_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 380 "parsecoq.mly"
           ( _1 )
# 1247 "parsecoq.ml"
               : 'id_or_expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_expr) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    Obj.repr(
# 386 "parsecoq.mly"
      ( Hyp (_2, _4, 1) )
# 1255 "parsecoq.ml"
               : 'hyp_def))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_expr) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    Obj.repr(
# 388 "parsecoq.mly"
      ( let (params, expr) = get_params _4 in
        Def (DefReal (_2, _2, params, expr, None)) )
# 1264 "parsecoq.ml"
               : 'hyp_def))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : 'compact_args) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'typ) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    Obj.repr(
# 391 "parsecoq.mly"
      (
       let compact_params = _3 in
       let (other_params, expr) = get_params _7 in
       Def (DefReal (_2, _2, (compact_params @ other_params), expr, None))
      )
# 1278 "parsecoq.ml"
               : 'hyp_def))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 10 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 9 : 'compact_args) in
    let _6 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _9 = (Parsing.peek_val __caml_parser_env 3 : 'typ) in
    let _11 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    Obj.repr(
# 398 "parsecoq.mly"
      (
       let compact_params = _3 in
       let (other_params, expr) = get_params _11 in
       Def (DefReal (_2, _2, (compact_params @ other_params), expr, Some _6))
      )
# 1293 "parsecoq.ml"
               : 'hyp_def))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 9 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 8 : 'compact_args) in
    let _5 = (Parsing.peek_val __caml_parser_env 6 : 'typ) in
    let _7 = (Parsing.peek_val __caml_parser_env 4 : 'expr) in
    let _10 = (Parsing.peek_val __caml_parser_env 1 : 'expr) in
    Obj.repr(
# 405 "parsecoq.mly"
      ( Def (DefRec (_7, _2, _3, _10)) )
# 1304 "parsecoq.ml"
               : 'hyp_def))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : 'binding_list) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'constr_list) in
    Obj.repr(
# 407 "parsecoq.mly"
      ( mk_inductive _2 _3 _7 )
# 1314 "parsecoq.ml"
               : 'hyp_def))
; (fun __caml_parser_env ->
    Obj.repr(
# 412 "parsecoq.mly"
                                                         ( [] )
# 1320 "parsecoq.ml"
               : 'compact_args))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'typ) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'compact_args) in
    Obj.repr(
# 413 "parsecoq.mly"
                                                     ( (evar _2) :: _6 )
# 1329 "parsecoq.ml"
               : 'compact_args))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'hyp_def) in
    Obj.repr(
# 418 "parsecoq.mly"
                               (
      (* FIXME activate this warning at some point.
      Error.warn "use of obsolete \"Depends on\" syntax";
      *)
      (_3, true)
    )
# 1341 "parsecoq.ml"
               : 'dep_hyp_def))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'hyp_def) in
    Obj.repr(
# 424 "parsecoq.mly"
                               ( (_2, true) )
# 1348 "parsecoq.ml"
               : 'dep_hyp_def))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'hyp_def) in
    Obj.repr(
# 425 "parsecoq.mly"
                               ( (_1, false) )
# 1355 "parsecoq.ml"
               : 'dep_hyp_def))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'dep_hyp_def) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'hyp_def_list) in
    Obj.repr(
# 429 "parsecoq.mly"
                               ( _1 :: _2 )
# 1363 "parsecoq.ml"
               : 'hyp_def_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 430 "parsecoq.mly"
                               ( [] )
# 1369 "parsecoq.ml"
               : 'hyp_def_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'constr_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'constr_list) in
    Obj.repr(
# 435 "parsecoq.mly"
      ( (_2, _4) :: _5 )
# 1378 "parsecoq.ml"
               : 'constr_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 437 "parsecoq.mly"
      ( [] )
# 1384 "parsecoq.ml"
               : 'constr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'arg_type) in
    Obj.repr(
# 441 "parsecoq.mly"
                                      ( [] )
# 1391 "parsecoq.ml"
               : 'constr_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arg_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'constr_type) in
    Obj.repr(
# 442 "parsecoq.mly"
                                      ( _1 :: _3 )
# 1399 "parsecoq.ml"
               : 'constr_type))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'arg_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'constr_type) in
    Obj.repr(
# 444 "parsecoq.mly"
                                      ( _2 :: _4 )
# 1407 "parsecoq.ml"
               : 'constr_type))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'arg_type) in
    Obj.repr(
# 448 "parsecoq.mly"
                                      ( _2 )
# 1414 "parsecoq.ml"
               : 'arg_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'idlist) in
    Obj.repr(
# 449 "parsecoq.mly"
                                      ( (_1, _2) )
# 1422 "parsecoq.ml"
               : 'arg_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 453 "parsecoq.mly"
                                      ( () )
# 1428 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 454 "parsecoq.mly"
                                      ( () )
# 1436 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 455 "parsecoq.mly"
                                      ( () )
# 1443 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 456 "parsecoq.mly"
                                      ( () )
# 1450 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 457 "parsecoq.mly"
                                      ( () )
# 1458 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 458 "parsecoq.mly"
                                      ( () )
# 1465 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 459 "parsecoq.mly"
                                      ( () )
# 1472 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 460 "parsecoq.mly"
                                      ( () )
# 1479 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'junk) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 461 "parsecoq.mly"
                                      ( () )
# 1487 "parsecoq.ml"
               : 'junk))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'junk) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'junk) in
    Obj.repr(
# 462 "parsecoq.mly"
                                      ( () )
# 1495 "parsecoq.ml"
               : 'junk))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : string * (Phrase.phrase * bool) list)
;;
